@@ -32,6 +32,16 @@ get_scaled(const char *buffer, const char *key)
 }
 
 
+char *
+skip_token (const char *p)
+{
+	p = next_token(p);
+	while (*p && !isspace(*p)) p++;
+	p = next_token(p);
+	return (char *)p;
+}
+
+
 /*
  * Read functions
  */
@@ -56,6 +66,8 @@ int try_file_to_buffer(char *buffer, const char *format, ...)
 
 	va_end(pa);
 
+	buffer [0] = '\0';
+
 	if((fd = open (path, O_RDONLY)) < 0)
 		return TRY_FILE_TO_BUFFER_OPEN;
 
