@@ -1,4 +1,4 @@
-/* $Id: netload.c,v 1.31.2.1 2004/11/15 15:02:43 bdejean Exp $ */
+/* $Id: netload.c,v 1.34 2005/03/25 13:23:24 bdejean Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -21,10 +21,14 @@
    Boston, MA 02111-1307, USA.
 */
 
+#include <config.h>
+
 #include <glibtop.h>
 #include <glibtop/error.h>
 #include <glibtop/netload.h>
 
+#include "glibtop_private.h"
+
 #include <errno.h>
 #include <string.h>
 
@@ -129,7 +133,7 @@ static void get_ipv6(glibtop *server, glibtop_netload *buf,
 
 	if(getifaddrs (&ifa0) != 0)
 	{
-		glibtop_warn_r(server, "getifaddrs failed : %s", strerror(errno));
+		glibtop_warn_r(server, "getifaddrs failed : %s", g_strerror(errno));
 		return;
 	}
 
