@@ -1,6 +1,4 @@
-/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 4 -*- */
-
-/* $Id$ */
+/* $Id: ppp.c,v 1.11 2003/10/19 16:55:51 carlos Exp $ */
 
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
@@ -27,29 +25,20 @@
 #include <glibtop/error.h>
 #include <glibtop/ppp.h>
 
-#include <glibtop_suid.h>
-
 static const unsigned long _glibtop_sysdeps_ppp = 0;
 
 /* Init function. */
 
-int
+void
 glibtop_init_ppp_p (glibtop *server)
 {
-    server->sysdeps.ppp = _glibtop_sysdeps_ppp;
-
-    return 0;
+	server->sysdeps.ppp = _glibtop_sysdeps_ppp;
 }
 
 /* Provides PPP/ISDN information. */
 
-int
-glibtop_get_ppp_p (glibtop *server, glibtop_ppp *buf, unsigned short device,
-		   unsigned short isdn)
+void
+glibtop_get_ppp_p (glibtop *server, glibtop_ppp *buf, unsigned short device)
 {
-    glibtop_init_p (server, GLIBTOP_SYSDEPS_PPP, 0);
-	
-    memset (buf, 0, sizeof (glibtop_ppp));
-
-    return 0;
+	memset (buf, 0, sizeof (glibtop_ppp));
 }
